@@ -25,13 +25,36 @@ static apr_status_t file_dup(apr_file_t **new_file,
                              int which_dup)
 {
     int rv;
-    
+#ifdef HAVE_DUP3
+    int flags = 0;
+#endif
+
     if (which_dup == 2) {
         if ((*new_file) == NULL) {
             /* We can't dup2 unless we have a valid new_file */
             return APR_EINVAL;
         }
+#ifdef HAVE_DUP3
+        if (!((*new_file)->flags & (APR_FOPEN_NOCLEANUP|APR_INHERIT)))
+            flags |= O_CLOEXEC;
+        rv = dup3(old_file->filedes, (*new_file)->filedes, flags);
+#else
         rv = dup2(old_file->filedes, (*new_file)->filedes);
+        if (!((*new_file)->flags & (APR_FOPEN_NOCLEANUP|APR_INHERIT))) {
+            int flags;
+
+            if (rv == -1)
+                return errno;
+
+            if ((flags = fcntl((*new_file)->filedes, F_GETFD)) == -1)
+                return errno;
+
+            flags |= FD_CLOEXEC;
+            if (fcntl((*new_file)->filedes, F_SETFD, flags) == -1)
+                return errno;
+
+        }
+#endif
     } else {
         rv = dup(old_file->filedes);
     }
@@ -83,12 +106,12 @@ static apr_status_t file_dup(apr_file_t **new_file,
     }
 
     /* apr_file_dup() retains all old_file flags with the exceptions
-     * of APR_INHERIT and APR_FILE_NOCLEANUP.
+     * of APR_INHERIT and APR_FOPEN_NOCLEANUP.
      * The user must call apr_file_inherit_set() on the dupped 
      * apr_file_t when desired.
      */
     (*new_file)->flags = old_file->flags
-                       & ~(APR_INHERIT | APR_FILE_NOCLEANUP);
+                       & ~(APR_INHERIT | APR_FOPEN_NOCLEANUP);
 
     apr_pool_cleanup_register((*new_file)->pool, (void *)(*new_file),
                               apr_unix_file_cleanup, 
@@ -118,8 +141,7 @@ APR_DECLARE(apr_status_t) apr_file_setaside(apr_file_t **new_file,
                                             apr_file_t *old_file,
                                             apr_pool_t *p)
 {
-    *new_file = (apr_file_t *)apr_palloc(p, sizeof(apr_file_t));
-    memcpy(*new_file, old_file, sizeof(apr_file_t));
+    *new_file = (apr_file_t *)apr_pmemdup(p, old_file, sizeof(apr_file_t));
     (*new_file)->pool = p;
     if (old_file->buffered) {
         (*new_file)->buffer = apr_palloc(p, old_file->bufsize);
@@ -141,7 +163,9 @@ APR_DECLARE(apr_status_t) apr_file_setaside(apr_file_t **new_file,
     if (old_file->fname) {
         (*new_file)->fname = apr_pstrdup(p, old_file->fname);
     }
-    if (!(old_file->flags & APR_FILE_NOCLEANUP)) {
+    if (!(old_file->flags & APR_FOPEN_NOCLEANUP)) {
+        apr_pool_cleanup_kill(old_file->pool, (void *)old_file,
+                              apr_unix_file_cleanup);
         apr_pool_cleanup_register(p, (void *)(*new_file), 
                                   apr_unix_file_cleanup,
                                   ((*new_file)->flags & APR_INHERIT)
@@ -150,8 +174,6 @@ APR_DECLARE(apr_status_t) apr_file_setaside(apr_file_t **new_file,
     }
 
     old_file->filedes = -1;
-    apr_pool_cleanup_kill(old_file->pool, (void *)old_file,
-                          apr_unix_file_cleanup);
 #ifndef WAITIO_USES_POLL
     (*new_file)->pollset = NULL;
 #endif
