@@ -21,6 +21,10 @@
 #ifndef APR_TEST_UTIL
 #define APR_TEST_UTIL
 
+/* XXX: FIXME - these all should become much more utilitarian 
+ * and part of apr, itself
+ */
+
 #ifdef WIN32
 #ifdef BINPATH
 #define TESTBINPATH APR_STRINGIFY(BINPATH) "/"
@@ -60,7 +64,9 @@ abts_suite *testatomic(abts_suite *suite);
 abts_suite *testdir(abts_suite *suite);
 abts_suite *testdso(abts_suite *suite);
 abts_suite *testdup(abts_suite *suite);
+abts_suite *testencode(abts_suite *suite);
 abts_suite *testenv(abts_suite *suite);
+abts_suite *testescape(abts_suite *suite);
 abts_suite *testfile(abts_suite *suite);
 abts_suite *testfilecopy(abts_suite *suite);
 abts_suite *testfileinfo(abts_suite *suite);
@@ -72,6 +78,7 @@ abts_suite *testglobalmutex(abts_suite *suite);
 abts_suite *testhash(abts_suite *suite);
 abts_suite *testipsub(abts_suite *suite);
 abts_suite *testlock(abts_suite *suite);
+abts_suite *testcond(abts_suite *suite);
 abts_suite *testlfs(abts_suite *suite);
 abts_suite *testmmap(abts_suite *suite);
 abts_suite *testnames(abts_suite *suite);
@@ -83,7 +90,6 @@ abts_suite *testpool(abts_suite *suite);
 abts_suite *testproc(abts_suite *suite);
 abts_suite *testprocmutex(abts_suite *suite);
 abts_suite *testrand(abts_suite *suite);
-abts_suite *testrand2(abts_suite *suite);
 abts_suite *testsleep(abts_suite *suite);
 abts_suite *testshm(abts_suite *suite);
 abts_suite *testsock(abts_suite *suite);
@@ -98,5 +104,6 @@ abts_suite *testtime(abts_suite *suite);
 abts_suite *testud(abts_suite *suite);
 abts_suite *testuser(abts_suite *suite);
 abts_suite *testvsn(abts_suite *suite);
+abts_suite *testskiplist(abts_suite *suite);
 
 #endif /* APR_TEST_INCLUDES */
